[![Build Status](https://travis-ci.org/ylab-hi/ScanCE.svg?branch=master&status=passed)](https://travis-ci.org/ylab-hi/ScanCE)
# ScanCE

A computational workflow for cryptic exon identification.


Prerequisites
----------------
`ScanCE` runs under Python 3.6+ and is available through python3-pip.

# Installation

The recommended way to install `ScanCE` is using [pip](https://pip.pypa.io/en/stable/).



```
